API — django-icons 0.1.0 documentation

# API

## icon

`django_icons.` `icon`(name, *args, **kwargs)

  Render an icon

  Parameters:

  > name
  >   The name of the icon to be rendered
  > title

  >   The title attribute for the icon

  >   default: | None (no title attribute rendered)

  > renderer

  >   The renderer to use for the icon

  >   default: | The default renderer as per `settings.py`, or ultimately FontAwesomeRenderer.

  Usage:

      icon(name)

  Example:

      icon('pencil')
      icon('trash', title='Delete')